pub enum DenialError {
Forbidden,
NotFound,
}Expand description
HTTP denial category returned by the axum adapter.
Variants
Forbidden
The resource may exist, but the principal is not allowed to access it.
NotFound
The denial must be presented as a generic missing resource.