pub struct DenialResponseConfig { /* private fields */ }Expand description
Presentation settings for policy denials.
Implementations
Sourceimpl DenialResponseConfig
impl DenialResponseConfig
Sourcepub fn with_forbidden_fallback(self, message: impl Into<String>) -> Self
pub fn with_forbidden_fallback(self, message: impl Into<String>) -> Self
Uses this message when a forbidden denial has no stable reason.
Uses this message for hidden denials unless a generic hidden reason is configured.
Renders hidden denials through the catalog using this generic reason code.
The configured code is a replacement for the hidden policy reason, not the hidden policy reason itself.
Errors
Returns gatekeep::GatekeepError::EmptyIdentifier when reason is
empty or contains only whitespace.