pub struct ExpectedDenial { /* private fields */ }Expand description
Expected HTTP denial response.
Implementations
Sourceimpl ExpectedDenial
impl ExpectedDenial
Sourcepub fn with_message(self, message: impl Into<String>) -> Self
pub fn with_message(self, message: impl Into<String>) -> Self
Expects the denial body to contain this exact message.
Sourcepub fn with_reason(self, reason: impl Into<String>) -> Self
pub fn with_reason(self, reason: impl Into<String>) -> Self
Expects the denial body to contain this exact reason code.
Sourcepub fn without_reason(self) -> Self
pub fn without_reason(self) -> Self
Expects the denial body to omit its reason code.