pub struct Gatekeeper<R, A = NoopAuditSink, C = IdentityReasonCatalog, W = NoopPolicyObserver> { /* private fields */ }Expand description
Axum-friendly authorization boundary.
Implementations
Sourceimpl<R> Gatekeeper<R>
impl<R> Gatekeeper<R>
Sourceimpl<R, A, C, W> Gatekeeper<R, A, C, W>
impl<R, A, C, W> Gatekeeper<R, A, C, W>
Sourcepub fn with_audit_sink<NextAudit>(
self,
audit_sink: NextAudit,
) -> Gatekeeper<R, NextAudit, C, W>
pub fn with_audit_sink<NextAudit>( self, audit_sink: NextAudit, ) -> Gatekeeper<R, NextAudit, C, W>
Replaces the audit sink.
Sourcepub fn with_reason_catalog<NextCatalog>(
self,
reason_catalog: NextCatalog,
) -> Gatekeeper<R, A, NextCatalog, W>
pub fn with_reason_catalog<NextCatalog>( self, reason_catalog: NextCatalog, ) -> Gatekeeper<R, A, NextCatalog, W>
Replaces the reason catalog used for forbidden denials.
Sourcepub fn with_observer<NextObserver>(
self,
observer: NextObserver,
) -> Gatekeeper<R, A, C, NextObserver>
pub fn with_observer<NextObserver>( self, observer: NextObserver, ) -> Gatekeeper<R, A, C, NextObserver>
Replaces the side-channel decision observer.
Sourcepub fn with_denial_response(self, denial_response: DenialResponseConfig) -> Self
pub fn with_denial_response(self, denial_response: DenialResponseConfig) -> Self
Replaces denial presentation settings.
Sourcepub const fn with_audit_subjects(self, audit_subjects: AuditSubjects) -> Self
pub const fn with_audit_subjects(self, audit_subjects: AuditSubjects) -> Self
Controls whether audit entries include tenant and principal identifiers.
Sourceimpl<R, A, C, W> Gatekeeper<R, A, C, W>
impl<R, A, C, W> Gatekeeper<R, A, C, W>
Resolves facts, evaluates the policy, observes and audits the decision, and returns an axum rejection for denied requests.